@@ -1,8 +1,9 @@
 """Jupyter notebook rendering interface."""
 
+import copy
 import traceback
 import uuid
-from typing import List, Union
+from typing import Callable, List, Optional, Union
 
 import srsly
 from IPython import get_ipython
@@ -331,6 +332,15 @@ def format_label(label: str, label_name: str = 'Label', h: str = 'h3') -> str:
     return f'<{h}>{label_name.title()}: <kbd>{label}</kbd></{h}>'
 
 
+def format_list(items, format_fn: Optional[Union[Callable, str]] = None):
+    if format_fn is None:
+        format_fn = lambda x: x  # noqa: E731
+    elif isinstance(format_fn, str):
+        _format_fn = copy.deepcopy(format_fn)
+        format_fn = lambda x: f'<{_format_fn}>{x}</{_format_fn}>'  # noqa: E731
+    return '<ul>' + ''.join(f'<li>{format_fn(str(item))}</li>' for item in items) + '</ul>'
+
+
 def format_instance(instance: dict, **kwargs) -> str:
     """Format an `instancelib` instance.
 
@@ -418,13 +428,13 @@ class Render:
 
         Example:
             Writing your own custom rendering functions `format_title()` and `render_content()`, and give the tab 
-            a custom title `tab_title`, set the main UI color to red (`#ff0000`) and package link (URL in footer):
+            a custom title `default_title`, set the main UI color to red (`#ff0000`) and package link (URL in footer):
 
             >>> from genbase.ui.notebook import Render
             >>> class CustomRender(Render):
             ...     def __init__(self, *configs):
             ...         super().__init__(*configs)
-            ...         self.tab_title = 'My Custom Explanation'
+            ...         self.default_title = 'My Custom Explanation'
             ...         self.main_color = '#ff00000'
             ...         self.package_link = 'https://git.io/text_explainability'
             ...
@@ -436,6 +446,7 @@ class Render:
             ...         return type.replace(' ').title() if 'explanation' in type else type
         """
         self.configs = self.__validate_configs(configs)
+        self.default_title = 'Explanation'
         self.config_title = 'Config'
         self.main_color = Render.main_color
         self.package_link = Render.package_link
@@ -452,7 +463,7 @@ class Render:
     @property
     def tab_title(self, **renderargs) -> str:
         """Title of content tab."""
-        title = 'Explanation'
+        title = self.default_title
         titles = [config['META']['title'] for config in self.configs if 'title' in config['META']]
         if titles:
             title = ' | '.join(list(set(titles)))
